==> path_watcher-1.0.1.tar.gz: path_watcher/src/PathWatcherManager.php <==
<?php

namespace Drupal\path_watcher;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Session\AccountInterface;
use Drupal\path_alias\AliasManagerInterface;
use Drupal\path_watcher\Form\PathWatcherSettingsForm;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Event\TerminateEvent;

/**
 * Manages the saving of visits.
 */
class PathWatcherManager implements PathWatcherManagerInterface {

  /**
   * Constructs a new PathWatcherManager object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Session\AccountInterface $currentUser
   *   The current user.
   * @param \Drupal\Core\Routing\AdminContext $adminContext
   *   The admin context.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\path_alias\AliasManagerInterface $aliasManager
   *   The alias manager.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected AccountInterface $currentUser,
    protected AdminContext $adminContext,
    protected EntityTypeManagerInterface $entityTypeManager,
    protected AliasManagerInterface $aliasManager
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public function needSave(TerminateEvent $event): bool {
    // Skip drush requests.
    if (PHP_SAPI == 'cli') {
      return FALSE;
    }

    // Skip non successful responses and non HTML responses.
    $response = $event->getResponse();
    if (!$response->isSuccessful() || !str_contains($response->headers->get('Content-Type'), 'text/html')) {
      return FALSE;
    }

    // Skip non GET requests, AJAX requests and admin routes.
    $request = $event->getRequest();
    if (!$request->isMethod(Request::METHOD_GET) || $request->isXmlHttpRequest()) {
      return FALSE;
    }

    // Skip admin paths if configured.
    $config = $this->configFactory->get(PathWatcherSettingsForm::CONFIG_NAME);
    if ($config->get('skip_admin_paths') && $this->adminContext->isAdminRoute()) {
      return FALSE;
    }

    // Skip anonymous users if configured.
    if ($config->get('skip_anonymous') && $this->currentUser->isAnonymous()) {
      return FALSE;
    }

    // Skip users with configured usernames.
    $usernames = $config->get('skip_usernames');
    if ($usernames && in_array($this->currentUser->getAccountName(), $usernames)) {
      return FALSE;
    }

    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function saveVisit(string $path): VisitInterface {
    /** @var \Drupal\path_watcher\VisitInterface $visit */
    $path_entity = $this->getPathEntity($path);
    $visit = $this->entityTypeManager->getStorage('pw_visit')->create(['path' => $path_entity]);
    $visit->save();
    return $visit;
  }

  /**
   * {@inheritdoc}
   */
  public function getPathHash(string &$path): string {
    $path = $this->aliasManager->getPathByAlias($path);
    return hash(static::HASH_ALGO, $path);
  }

  /**
   * {@inheritdoc}
   */
  public function getPathEntity(string $path): PathInterface {
    $hash = $this->getPathHash($path);
    $path_storage = $this->entityTypeManager->getStorage('pw_path');
    /** @var \Drupal\path_watcher\PathInterface $path_entity */
    if (!$path_entity = $path_storage->load($hash)) {
      $path_entity = $path_storage->create([
        'hash' => $hash,
        'path' => $path,
        'path_alias' => $this->aliasManager->getAliasByPath($path),
      ]);
      $path_entity->save();
    }
    return $path_entity;
  }

}

==> path_watcher-1.0.2.tar.gz: path_watcher/src/PathWatcherManager.php <==
<?php

namespace Drupal\path_watcher;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Session\AccountInterface;
use Drupal\path_alias\AliasManagerInterface;
use Drupal\path_watcher\Form\PathWatcherSettingsForm;
use Symfony\Component\HttpKernel\Event\TerminateEvent;

/**
 * Manages the saving of visits.
 */
class PathWatcherManager implements PathWatcherManagerInterface {

  /**
   * Constructs the object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Session\AccountInterface $currentUser
   *   The current user.
   * @param \Drupal\Core\Routing\AdminContext $adminContext
   *   The admin context.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\path_alias\AliasManagerInterface $aliasManager
   *   The alias manager.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected AccountInterface $currentUser,
    protected AdminContext $adminContext,
    protected EntityTypeManagerInterface $entityTypeManager,
    protected AliasManagerInterface $aliasManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function needSave(TerminateEvent $event): bool {
    // Skip drush requests.
    if (PHP_SAPI == 'cli') {
      return FALSE;
    }
    // Skip non successful responses.
    $response = $event->getResponse();
    if (!$response->isSuccessful()) {
      return FALSE;
    }

    $config = $this->configFactory->get(PathWatcherSettingsForm::CONFIG_NAME)->get();
    if ($config['content_type'] && !preg_match($config['content_type'], $response->headers->get('Content-Type'))) {
      return FALSE;
    }
    $request = $event->getRequest();
    if ($config['skip_xml_http_request'] && $request->isXmlHttpRequest()) {
      return FALSE;
    }
    if ($config['methods'] && empty($config['methods'][$request->getMethod()])) {
      return FALSE;
    }
    if ($config['skip_admin_paths'] && $this->adminContext->isAdminRoute()) {
      return FALSE;
    }
    if ($config['skip_roles'] && array_intersect($this->currentUser->getRoles(), $config['skip_roles'])) {
      return FALSE;
    }
    if ($config['skip_usernames'] && in_array($this->currentUser->getAccountName(), $config['skip_usernames'])) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function saveVisit(string $path): VisitInterface {
    /** @var \Drupal\path_watcher\VisitInterface $visit */
    $visit = $this->entityTypeManager->getStorage('pw_visit')->create(['path' => $this->getPathEntity($path)]);
    $visit->save();
    return $visit;
  }

  /**
   * {@inheritdoc}
   */
  public function getPathHash(string &$path): string {
    $path = $this->aliasManager->getPathByAlias($path);
    return hash(static::HASH_ALGO, $path);
  }

  /**
   * {@inheritdoc}
   */
  public function getPathEntity(string $path): PathInterface {
    $hash = $this->getPathHash($path);
    $path_storage = $this->entityTypeManager->getStorage('pw_path');
    if (!$path_entity = $path_storage->load($hash)) {
      /** @var \Drupal\path_watcher\PathInterface $path_entity */
      $path_entity = $path_storage->create([
        'hash' => $hash,
        'path' => $path,
        'path_alias' => $this->aliasManager->getAliasByPath($path),
      ]);
      $path_entity->save();
    }
    return $path_entity;
  }

}
